@@ -16,6 +16,9 @@
 #'          behaviour in Firefox.
 #' @param title \code{string} to customize the title of the UI window.
 #' @param editor \code{character} either "leaflet.extras" or "leafpm"
+#' @param editorOptions \code{list} of options suitable for passing to
+#'     either \code{leaflet.extras::addDrawToolbar} or
+#'     \code{leafpm::addPmToolbar}.
 #' @param ... additional arguments passed on to \code{\link{editMap}}.
 #'
 #' @details
@@ -35,6 +38,7 @@ drawFeatures = function(map = NULL,
                         viewer = shiny::paneViewer(),
                         title = "Draw Features",
                         editor = c("leaflet.extras", "leafpm"),
+                        editorOptions = list(),
                         ...) {
   res = editMap(x = map,
                 sf = sf,
@@ -42,6 +46,7 @@ drawFeatures = function(map = NULL,
                 viewer = viewer,
                 title = title,
                 editor = editor,
+                editorOptions = editorOptions,
                 ...)
   if (!inherits(res, "sf") && is.list(res)) res = res$finished
   return(res)
